Learn R Programming

GLmom (version 1.3.1)

PhliuAgromet: Phliu Agrometeorological Station Data

Description

Climate or meteorological data from the Phliu Agrometeorological Station for extreme value analysis.

Usage

PhliuAgromet

Arguments

Format

A data frame with 40 rows and 9 columns:

Station.ID

Station identifier (character)

year

Year of observation (numeric, 1984-2023)

prec

Annual maximum daily precipitation in mm (numeric)

Name

Station name (character)

zone

Climate zone code (character)

latitude

Station latitude in degrees (numeric)

longitude

Station longitude in degrees (numeric)

Starting.year

Record start year (integer)

Ending.year

Record end year (numeric)

References

Shin, Y., Shin, Y., Park, J., & Park, J. S. (2025). Generalized method of L-moment estimation for stationary and nonstationary extreme value models. arXiv preprint arXiv:2512.20385. tools:::Rd_expr_doi("10.48550/arXiv.2512.20385")

Examples

Run this code
data(PhliuAgromet)
head(PhliuAgromet)

Run the code above in your browser using DataLab