Learn R Programming

GLmom (version 1.3.1)

Trehafod: Trehafod River Flow Data

Description

Annual maximum river flow data from the Trehafod gauging station in Wales, UK. This dataset is commonly used for demonstrating non-stationary extreme value analysis methods.

Usage

Trehafod

Arguments

Format

A data frame with 53 rows and 2 columns:

Year

Year of observation (integer, 1968-2021)

r1

Annual maximum river flow in cubic meters per second (m^3/s)

References

Shin, Y., Shin, Y. & Park, J.-S. (2025). Building nonstationary extreme value model using L-moments. Journal of the Korean Statistical Society, 54, 947-970. tools:::Rd_expr_doi("10.1007/s42952-025-00325-3")

Examples

Run this code
data(Trehafod)
head(Trehafod)

# \donttest{
# Fit non-stationary GEV11 model
result <- glme.gev11(Trehafod$r1, ntry = 5)
print(result$para.glme)
# }

Run the code above in your browser using DataLab