Learn R Programming

GLmom (version 1.3.1)

cov.interp: Interpolate missing covariance matrices across submodels

Description

Internal function that fills in missing 2x2 covariance matrices for submodels using natural spline interpolation across the shape parameter.

Usage

cov.interp(numk, para3, cov2 = NULL)

Value

Array (2 x 2 x numk) of covariance matrices with missing values filled by interpolation.

Arguments

numk

Number of candidate submodels.

para3

Matrix (numk x 3) of submodel parameters.

cov2

List of 2x2 covariance matrices (one per submodel).