Learn R Programming

GLmom (version 1.3.1)

delta.gev: Delta method variance and cross-covariance for GEV quantiles

Description

Internal function that computes delta method variances for GEV quantile estimates. Can compute either the variance from a full 3-parameter MLE (d3yes=TRUE) or the cross-covariance between two submodels with fixed xi (d3yes=FALSE).

Usage

delta.gev(
  gevf3 = NULL,
  mle3i = NULL,
  cov2i = NULL,
  mle3j = NULL,
  cov2j = NULL,
  quant = NULL,
  d3yes = FALSE
)

Value

A list containing:

v3

Variance for each quantile (if d3yes=TRUE)

covij

Cross-covariance for each quantile (if d3yes=FALSE)

Arguments

gevf3

Full MLE result list with cov and mle (used when d3yes=TRUE).

mle3i

Parameter vector for submodel i (used when d3yes=FALSE).

cov2i

2x2 covariance matrix for submodel i.

mle3j

Parameter vector for submodel j.

cov2j

2x2 covariance matrix for submodel j.

quant

Numeric vector of quantile probabilities.

d3yes

Logical. If TRUE, compute 3-parameter delta method variance.