Learn R Programming

GLmom (version 1.3.1)

emp.prior: Empirical prior for BMA based on MLE and LME

Description

Internal function that computes an empirical prior distribution for the shape parameter based on the range between MLE and LME estimates.

Usage

emp.prior(mle3, mle, lme)

Value

Numeric vector of prior probability values for each candidate.

Arguments

mle3

Matrix of candidate submodel parameters (numk x 3).

mle

MLE parameter estimates (mu, sigma, xi).

lme

LME parameter estimates (mu, sigma, xi).