Learn R Programming

GLmom (version 1.3.1)

gev.max: MLE for GEV distribution using constrained optimization

Description

Internal function that computes maximum likelihood estimates of GEV parameters using the Rsolnp constrained optimizer with multiple random starting points.

Usage

gev.max(xdat, ntry = 5)

Value

A list containing:

nsample

Sample size

conv

Convergence status (0 = success)

nllh

Negative log-likelihood at the optimum

mle

MLE estimates (mu, sigma, xi) in Hosking style

Arguments

xdat

Numeric vector of data.

ntry

Number of random starting points for optimization. Default is 5.