Learn R Programming

GLmom (version 1.3.1)

glme.gev: Generalized L-moments estimation for generalized extreme value distribution

Description

This function estimates the Generalized L-moments of Generalized Extreme Value distribution.

Usage

glme.gev(
  xdat,
  ntry = 10,
  pen = "beta",
  pen.choice = NULL,
  mu = -0.5,
  std = 0.2,
  p = 6,
  c1 = 10,
  c2 = 5
)

Value

The glme.gev function returns a list containing the following elements:

  • para.glme - The estimated parameters of the Generalized Extreme Value distribution.

  • para.lme - The L-moment estimates of the parameters.

  • covinv.lmom - The inverse of the covariance matrix of the L-moments.

  • lcovdet - The log determinant of the covariance matrix.

  • nllh.glme - The negative log-likelihood of the GLME solution.

  • pen - The penalization method used.

  • p_q - (for beta penalty) The p and q values used.

  • c1_c2 - (for beta penalty) The c1 and c2 values used.

  • mu_std - (for norm penalty) The mu and std values used.

Arguments

xdat

A numeric vector of data to be fitted.

ntry

Number of attempts for parameter estimation. Higher values increase the chance of finding a more accurate estimate by trying different initial conditions.

pen

Type of penalty function: Choose among "norm", "beta" (default), "ms", "park", "cannon", "cd", and "no" (without penalty function).

pen.choice

Choice number of penalty function specifying hyperparameters. For "beta": 1-6 correspond to different (p, c1, c2) combinations. For "norm": 1-4 correspond to different (mu, std) combinations.

mu

Mean hyperparameter for "norm" penalty function (default -0.5).

std

Standard deviation hyperparameter for "norm" penalty function (default 0.2).

p

Shape hyperparameter for "beta" penalty function (default 6).

c1

Scaling hyperparameter for "beta" penalty function (default 10).

c2

Upper limit hyperparameter for "beta" penalty function (default 5).

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

Details

The equations for the L-moments for LME of the GEVD are $$ \underline{\bf \lambda} - \underline{\bf l} = \underline{\bf 0},$$ where \( \underline{\bf \lambda} =(\lambda_1,\; \lambda_2,\; \lambda_3)^t \) and \(\underline{\bf l} =(l_1,\; l_2,\; l_3)^t\). Next, we define the generalized L-moments distance (GLD) as; $$(\underline{\bf \lambda} -\underline{\bf l})^t V^{-1} (\underline{\bf \lambda} -\underline{\bf l}),$$ where \(V\) is the variance-covariance matrix of the sample L-moments up to the third order.

References

Shin, Y., Shin, Y., Park, J. & Park, J.-S. (2025). Generalized method of L-moment estimation for stationary and nonstationary extreme value models. arXiv preprint arXiv:2512.20385. tools:::Rd_expr_doi("10.48550/arXiv.2512.20385")

See Also

glme.gev11 for non-stationary GEV estimation, ma.gev for model averaging estimation, glme.like for the objective function, quagev.NS for quantile computation.

Examples

Run this code
# Load example streamflow data
data(streamflow)
x <- streamflow$r1

# Estimate GEV parameters using beta penalty (default)
result <- glme.gev(x, ntry = 5)
print(result$para.glme)

# Using Martins-Stedinger penalty
result_ms <- glme.gev(x, ntry = 5, pen = "ms")
print(result_ms$para.glme)

Run the code above in your browser using DataLab