Learn R Programming

GLmom (version 1.3.1)

glme.gev11: Generalized L-moments estimation for non-stationary GEV11 model

Description

This function estimates parameters of the non-stationary GEV11 model where mu(t) = mu0 + mu1*t and sigma(t) = exp(sigma0 + sigma1*t).

Usage

glme.gev11(
  xdat,
  ntry = 10,
  ftol = 1e-06,
  init.rob = TRUE,
  glme.pre = "wls",
  opt.choose = "gof",
  pen = "beta",
  pen.choice = NULL,
  mu = -0.55,
  std = 0.3,
  p = 6,
  c1 = 10,
  c2 = 5
)

Value

A list containing:

  • para.glme - Proposed GLME estimates (5 parameters: mu0, mu1, sigma0, sigma1, xi).

  • para.lme - L-moment based estimates for non-stationary model.

  • para.gado - GN16 original estimates.

  • para.wls - Weighted least squares estimates (WLS).

  • strup.org - WLSE by strup method.

  • lme.sta - Stationary L-moment estimates.

  • pen - Penalty method used.

  • p_q - (for beta) p and q values.

  • c1_c2 - (for beta) c1 and c2 values.

Arguments

xdat

A numeric vector of data to be fitted.

ntry

Number of attempts for parameter estimation (default 10).

ftol

Tolerance for convergence (default 1e-6).

init.rob

Use robust regression for initialization (default TRUE).

glme.pre

Pre-estimation method: "wls" (default) or "gado".

opt.choose

Selection criterion: "gof" (default, goodness-of-fit) or "nllh" (negative log-likelihood).

pen

Type of penalty function: "norm", "beta" (default), "ms", "park", "cannon", "cd", or "no".

pen.choice

Choice number for penalty hyperparameters (default 6 for beta).

mu

Mean for normal penalty (default -0.55).

std

Std for normal penalty (default 0.3).

p

Shape for beta penalty (default 6).

c1

Scaling for beta penalty (default 10).

c2

Limit for beta penalty (default 5).

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

References

Shin, Y., Shin, Y., Park, J. & Park, J.-S. (2025). Generalized method of L-moment estimation for stationary and nonstationary extreme value models. arXiv preprint arXiv:2512.20385. tools:::Rd_expr_doi("10.48550/arXiv.2512.20385")

Shin, Y., Shin, Y. & Park, J.-S. (2025). Building nonstationary extreme value model using L-moments. Journal of the Korean Statistical Society, 54, 947-970. tools:::Rd_expr_doi("10.1007/s42952-025-00325-3")

See Also

glme.gev for stationary GEV estimation, nsgev for the pure L-moment wrapper (no penalty), quagev.NS for non-stationary quantile computation.

Examples

Run this code
# Load example streamflow data
data(streamflow)
x <- streamflow$r1

# \donttest{
# Estimate non-stationary GEV11 parameters
result <- glme.gev11(x, ntry = 5)
print(result$para.glme)  # Proposed GLME estimates
print(result$para.lme)  # L-moment based estimates
# }

Run the code above in your browser using DataLab