Learn R Programming

GLmom (version 1.3.1)

init.gevmax: Initialize parameters for GEV MLE estimation

Description

This function initializes parameters for GEV maximum likelihood estimation.

Usage

init.gevmax(data = NULL, ntry = NULL)

Value

A matrix with `ntry` rows and 3 columns, where each row represents a set of initial parameters (location, scale, shape) for the GEV distribution.

Arguments

data

A numeric vector of data to be fitted.

ntry

Number of initial parameter sets to generate.

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

Details

The function generates `ntry` sets of initial parameters for the GEV distribution. It uses L-moment estimates as a starting point and then generates additional sets of parameters using random perturbations.