Learn R Programming

GLmom (version 1.3.1)

init.glme: Initialize random starting values for GLME optimization

Description

Generates multiple random starting parameter sets for multi-start optimization in GLME estimation. Uses L-moment estimates as a base and adds random perturbations.

Usage

init.glme(xdat, ntry = ntry)

Value

A matrix with ntry rows and 3 columns (location, scale, shape), where each row is a candidate starting point for optimization.

Arguments

xdat

A numeric vector of data to be fitted.

ntry

Number of initial parameter sets to generate.

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

See Also

glme.gev which uses this function internally.

Examples

Run this code
data(streamflow)
inits <- init.glme(streamflow$r1, ntry = 5)
print(inits)

Run the code above in your browser using DataLab