Learn R Programming

GLmom (version 1.3.1)

lme.boots: L-moment estimation with bootstrap standard errors

Description

Internal function that computes L-moment estimates of GEV parameters and optionally performs bootstrap resampling to obtain covariance matrices and standard errors for quantile estimates.

Usage

lme.boots(data, B = NULL, quant, boot = TRUE, trim = NULL)

Value

A list containing:

lme

L-moment estimates (mu, sigma, xi)

qua.lme

Quantile estimates from LME

quant

Input quantile probabilities

cov.par

3x3 covariance of bootstrap parameter estimates (if boot=TRUE)

cov.lambda

3x3 covariance of bootstrap L-moments (if boot=TRUE)

qua.lme.se

SE of quantile estimates from bootstrap (if boot=TRUE)

Arguments

data

Numeric vector of data.

B

Number of bootstrap samples.

quant

Numeric vector of probabilities for quantile estimation.

boot

Logical. If TRUE (default), perform bootstrap.

trim

Left trimming level for L-moments (integer). Default is NULL (0).