Learn R Programming

GLmom (version 1.3.1)

magev.qqplot: Q-Q Diagnostic Plot for MAGEV

Description

Creates a 2x2 panel of Q-Q plots comparing observed vs. fitted quantiles for different estimation methods: MLE, LME, surrogate (MA), and REMLE.

Usage

magev.qqplot(data = NULL, zx = NULL)

Value

NULL. The function produces a plot as a side effect.

Arguments

data

A numeric vector of observed data.

zx

A list object returned by ma.gev with remle = TRUE.

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

Details

The function creates four Q-Q plots:

  • Upper left: MLE (Maximum Likelihood Estimation)

  • Upper right: LME (L-moment Estimation)

  • Lower left: Surrogate MA (Model Averaging surrogate)

  • Lower right: REMLE (Restricted MLE, if available)

Points close to the 45-degree diagonal line indicate good model fit.

References

Shin, Y., Shin, Y., & Park, J. S. (2026). Model averaging with mixed criteria for estimating high quantiles of extreme values: Application to heavy rainfall. Stochastic Environmental Research and Risk Assessment, 40(2), 47. tools:::Rd_expr_doi("10.1007/s00477-025-03167-x")

See Also

ma.gev for the main model averaging function, magev.rlplot for return level plots.

Examples

Run this code
data(streamflow)
qq <- c(seq(0.01, 0.99, by = 0.01), 0.995, 0.999)
zx <- ma.gev(streamflow$r1, quant = qq, weight = 'like1',
             numk = 9, varcom = FALSE, remle = TRUE)
magev.qqplot(data = streamflow$r1, zx = zx)

Run the code above in your browser using DataLab