Learn R Programming

GLmom (version 1.3.1)

magev.rlplot: Return Level Plot for MAGEV

Description

Displays fitted return levels with 95 return period on a log scale.

Usage

magev.rlplot(par = NULL, se.vec = NULL, data = NULL)

Value

NULL. The function produces a plot as a side effect.

Arguments

par

A numeric vector of GEV parameters (mu, sigma, xi) in Hosking style. Typically from zx$surr$par where zx is the output of ma.gev.

se.vec

A numeric vector of standard errors for the quantile estimates corresponding to the plotting positions. Typically from zx$ranw.se.ma.

data

A numeric vector of observed data (annual maxima).

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

Details

The plot shows:

  • Black line: Fitted return level curve

  • Blue lines: 95

  • Black points: Observed data at empirical return periods

The x-axis (return period) is on a log scale, ranging from 0.1 to 900 years.

References

Shin, Y., Shin, Y., & Park, J. S. (2026). Model averaging with mixed criteria for estimating high quantiles of extreme values: Application to heavy rainfall. Stochastic Environmental Research and Risk Assessment, 40(2), 47. tools:::Rd_expr_doi("10.1007/s00477-025-03167-x")

See Also

ma.gev for the main model averaging function, magev.qqplot for Q-Q diagnostic plots.

Examples

Run this code
data(streamflow)
ff <- c(seq(0.01, 0.09, by = 0.01), 0.1, 0.2, 0.3, 0.4, 0.5,
        0.6, 0.7, 0.8, 0.9, 0.93, 0.95, 0.98, 0.99,
        0.993, 0.995, 0.998, 0.999)
zx <- ma.gev(streamflow$r1, quant = ff, weight = 'like1',
             numk = 9, varcom = TRUE)
magev.rlplot(par = zx$surr$par, se.vec = zx$ranw.se.ma, data = streamflow$r1)

Run the code above in your browser using DataLab