Learn R Programming

GLmom (version 1.3.1)

make.qmax.gev11: Create maximum residual series for GEV11 model

Description

Internal function that constructs a modified residual series (qmax) from the data after removing estimated location trend, used for the GN16 time-varying moment method.

Usage

make.qmax.gev11(xdat = NULL, orig.para = NULL, rob = NULL)

Value

A list containing:

qmax

Modified residual series (numeric vector)

sig0

Log-scale intercept estimate

sig1

Log-scale trend estimate

Arguments

xdat

Numeric vector of data.

orig.para

Initial parameter vector (mu0, mu1, sigma0, sigma1, xi).

rob

Logical. If TRUE, use robust regression. If FALSE, use OLS.