Learn R Programming

GLmom (version 1.3.1)

nsgev: Non-stationary GEV Parameter Estimation

Description

Estimates parameters of a non-stationary Generalized Extreme Value (GEV) distribution using the L-moment-based algorithm from Shin et al. (2025, J. Korean Stat. Soc.). This function combines L-moments, goodness-of-fit measures, and robust regression.

This is a convenience wrapper around glme.gev11 with pen="no", providing compatibility with the original nsgev package interface.

Usage

nsgev(xdat, ntry = 20, ftol = 1e-06)

Value

A list containing:

  • para.prop - The proposed L-moment based estimates (mu0, mu1, sigma0, sigma1, xi).

  • precis - Precision of the optimization.

Arguments

xdat

A numeric vector of data to be fitted (e.g., annual maximum values).

ntry

Number of attempts for optimization (default 20).

ftol

Function tolerance for optimization (default 1e-6).

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

References

Shin, Y., Shin, Y. & Park, J.-S. (2025). Building nonstationary extreme value model using L-moments. Journal of the Korean Statistical Society, 54, 947-970. tools:::Rd_expr_doi("10.1007/s42952-025-00325-3")

See Also

glme.gev11 for the full GLME method with penalty functions, gado.prop_11 for detailed estimation results.

Examples

Run this code
data(Trehafod)
result <- nsgev(Trehafod$r1, ntry = 5)
print(result$para.prop)

Run the code above in your browser using DataLab