Learn R Programming

GLmom (version 1.3.1)

pargev.kfix: GEV parameter estimation with fixed shape parameter

Description

Estimates GEV location and scale parameters from L-moments while keeping the shape parameter fixed at a user-specified value. Modified from lmomco::pargev().

Usage

pargev.kfix(lmom, kfix = 0.1, checklmom = TRUE, ...)

Value

A list with components:

type

Character "gev"

para

Numeric vector of GEV parameters (xi=location, alpha=scale, kappa=shape)

source

Character "pargev"

Arguments

lmom

L-moments object.

kfix

Fixed shape parameter value.

checklmom

Whether to check L-moment validity.

...

Additional arguments.

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

References

Hosking, J. R. M. (1990). L-moments: Analysis and estimation of distributions using linear combinations of order statistics. Journal of the Royal Statistical Society, Series B, 52(1), 105-124. tools:::Rd_expr_doi("10.1111/j.2517-6161.1990.tb01775.x")

See Also

glme.gev for GLME estimation, pargev for the original L-moment GEV fitting.

Examples

Run this code
data(streamflow)
lmom <- lmomco::lmoms(streamflow$r1, nmom = 3)
pargev.kfix(lmom, kfix = -0.1)

Run the code above in your browser using DataLab