Learn R Programming

GLmom (version 1.3.1)

pk.norm.stnary: Normal preference function for shape parameter (stationary GEV)

Description

Computes a normal distribution-based preference (penalty) function value for the GEV shape parameter. The alias new_pf_norm is provided for backward compatibility.

Usage

pk.norm.stnary(para = NULL, mu = NULL, std = NULL)

new_pf_norm(para = NULL, mu = NULL, std = NULL)

Value

Preference function value (scalar).

Arguments

para

A vector of GEV parameters.

mu

Mean for normal distribution.

std

Standard deviation for normal distribution.

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

References

Shin, Y., Shin, Y., Park, J. & Park, J.-S. (2025). Generalized method of L-moment estimation for stationary and nonstationary extreme value models. arXiv preprint arXiv:2512.20385. tools:::Rd_expr_doi("10.48550/arXiv.2512.20385")

See Also

pk.beta.stnary for the beta penalty, MS_pk for the Martins-Stedinger penalty, glme.gev which uses these penalty functions.

Examples

Run this code
# Normal preference with mean=-0.5, sd=0.2 at xi=-0.2
pk.norm.stnary(para = c(100, 20, -0.2), mu = -0.5, std = 0.2)

Run the code above in your browser using DataLab