Learn R Programming

GLmom (version 1.3.1)

prior.beta.stnary.ma: Beta prior for model averaging

Description

Internal function that computes a Beta distribution prior probability for a candidate shape parameter in model averaging.

Usage

prior.beta.stnary.ma(x = NULL, xi_lme = NULL, p = 2, q = 5, al, bl)

Value

Prior probability value (scalar).

Arguments

x

Shape parameter value to evaluate.

xi_lme

L-moment estimate of xi (unused in this version).

p

Beta shape parameter p. Default is 2.

q

Beta shape parameter q. Default is 5.

al

Lower bound of support.

bl

Upper bound of support.