Learn R Programming

GLmom (version 1.3.1)

quagev.NS: Quantile function for non-stationary GEV models

Description

Calculates quantiles for non-stationary GEV models including GEV11, GEV10, GEV20, and stationary GEV00.

Usage

quagev.NS(f = NULL, para = NULL, nsample = NULL, model = NULL)

Value

A matrix of quantiles (nsample x length(f)) or a vector if f is scalar.

Arguments

f

Probability (or vector of probabilities) for quantile calculation.

para

Parameter vector. For GEV11: (mu0, mu1, sigma0, sigma1, xi).

nsample

Number of time points (sample size).

model

Model type: "gev11", "gev10", "gev20", "gev01", or "gev00"/"gev".

Author

Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park

References

Shin, Y., Shin, Y., Park, J. & Park, J.-S. (2025). Generalized method of L-moment estimation for stationary and nonstationary extreme value models. arXiv preprint arXiv:2512.20385. tools:::Rd_expr_doi("10.48550/arXiv.2512.20385")

See Also

glme.gev11 for non-stationary GEV estimation, glme.gev for stationary GEV estimation.

Examples

Run this code
# GEV11 model: time-varying quantiles
para <- c(84.55, 1.03, 2.91, 0.009, -0.08)  # mu0, mu1, sigma0, sigma1, xi
q99 <- quagev.NS(f = 0.99, para = para, nsample = 53, model = "gev11")
print(q99)

Run the code above in your browser using DataLab