Internal function that fills in missing 2x2 covariance matrices for submodels using natural spline interpolation across the shape parameter.
cov.interp(numk, para3, cov2 = NULL)Array (2 x 2 x numk) of covariance matrices with missing values filled by interpolation.
Number of candidate submodels.
Matrix (numk x 3) of submodel parameters.
List of 2x2 covariance matrices (one per submodel).