Internal function that computes an empirical prior distribution for the shape parameter based on the range between MLE and LME estimates.
emp.prior(mle3, mle, lme)Numeric vector of prior probability values for each candidate.
Matrix of candidate submodel parameters (numk x 3).
MLE parameter estimates (mu, sigma, xi).
LME parameter estimates (mu, sigma, xi).