This function initializes parameters for GEV maximum likelihood estimation.
init.gevmax(data = NULL, ntry = NULL)A matrix with `ntry` rows and 3 columns, where each row represents a set of initial parameters (location, scale, shape) for the GEV distribution.
A numeric vector of data to be fitted.
Number of initial parameter sets to generate.
Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park
The function generates `ntry` sets of initial parameters for the GEV distribution. It uses L-moment estimates as a starting point and then generates additional sets of parameters using random perturbations.