Internal function that computes L-moment estimates of GEV parameters and optionally performs bootstrap resampling to obtain covariance matrices and standard errors for quantile estimates.
lme.boots(data, B = NULL, quant, boot = TRUE, trim = NULL)A list containing:
L-moment estimates (mu, sigma, xi)
Quantile estimates from LME
Input quantile probabilities
3x3 covariance of bootstrap parameter estimates (if boot=TRUE)
3x3 covariance of bootstrap L-moments (if boot=TRUE)
SE of quantile estimates from bootstrap (if boot=TRUE)
Numeric vector of data.
Number of bootstrap samples.
Numeric vector of probabilities for quantile estimation.
Logical. If TRUE (default), perform bootstrap.
Left trimming level for L-moments (integer). Default is NULL (0).