Internal function that constructs a modified residual series (qmax) from the data after removing estimated location trend, used for the GN16 time-varying moment method.
make.qmax.gev11(xdat = NULL, orig.para = NULL, rob = NULL)A list containing:
Modified residual series (numeric vector)
Log-scale intercept estimate
Log-scale trend estimate
Numeric vector of data.
Initial parameter vector (mu0, mu1, sigma0, sigma1, xi).
Logical. If TRUE, use robust regression. If FALSE, use OLS.