pk.beta.stnary: Beta preference function for stationary GEV
Description
Computes a Beta distribution-based adaptive preference (penalty) function
for the GEV shape parameter. The hyperparameters are adapted based on the
L-moment estimate of the shape parameter.
Shape parameter q (optional, if provided uses fixed limits).
c0
Limit parameter (default 0.3).
c1
Scaling parameter (default 10).
c2
Upper limit parameter (default 5).
Author
Yonggwan Shin, Seokkap Ko, Jihong Park, Yire Shin, Jeong-Soo Park
References
Shin, Y., Shin, Y., Park, J. & Park, J.-S. (2025). Generalized method of
L-moment estimation for stationary and nonstationary extreme value models.
arXiv preprint arXiv:2512.20385. tools:::Rd_expr_doi("10.48550/arXiv.2512.20385")
See Also
pk.norm.stnary for the normal penalty,
MS_pk for the Martins-Stedinger penalty,
glme.gev which uses these penalty functions.