Internal function that computes a Beta distribution prior probability for a candidate shape parameter in model averaging.
prior.beta.stnary.ma(x = NULL, xi_lme = NULL, p = 2, q = 5, al, bl)Prior probability value (scalar).
Shape parameter value to evaluate.
L-moment estimate of xi (unused in this version).
Beta shape parameter p. Default is 2.
Beta shape parameter q. Default is 5.
Lower bound of support.
Upper bound of support.